//import required modlues from d3
import { select, layout, json } from 'd3';
//set the height and width
const width = 960,
  height = 500;
//create svg element
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

//make a force layout
const force = layout
  .force()
  .gravity(0.1)
  .distance(200)
  .charge(-600)
  .size([width, height]);

//invoke the json data
const data = json('data.json', function (json) {
  force
    .nodes(json.nodes)
    .links(json.links)
    .start();
  // connect the node with link
  const link = svg
    .selectAll('.link')
    .data(json.links)
    .enter()
    .append('line')
    .attr('class', 'link')
    .style('stroke-width', function (d) {
      d.weight;
    });

  //Append the node
  const node = svg
    .selectAll('.node')
    .data(json.nodes)
    .enter()
    .append('g')
    .attr('class', 'node')
    .call(force.drag);

  // set the shape
  node.append('circle').attr('r', '15');
  //add the label
  node
    .append('text')
    .attr('dx', 15)
    .attr('dy', '.5em')
    .text(function (d) {
      return d.name;
    });

  //position the node
  force.on('tick', function () {
    link
      .attr('x1', function (d) {
        return d.source.x;
      })
      .attr('y1', function (d) {
        return d.source.y;
      })
      .attr('x2', function (d) {
        return d.target.x;
      })
      .attr('y2', function (d) {
        return d.target.y;
      });

    node.attr('transform', function (d) {
      return 'translate(' + d.x + ',' + d.y + ')';
    });
  });
});
